@@ -19,3 +19,9 @@ test_that("vis_compare will not accept two dataframes of differing dims",{
   expect_error(
     vis_compare(iris, iris_add))
 })
+
+test_that("vis_compare fails when an object of the wrong class is provided", {
+  testthat::expect_error(vis_compare(iris, AirPassengers))
+  testthat::expect_error(vis_compare(AirPassengers, iris))
+  testthat::expect_error(vis_compare(AirPassengers, AirPassengers))
+})
